import { select , geoMercator, json, geoPath, event,zoom } from 'd3';
const width = document.body.clientWidth;
const height = document.body.clientHeight;
const svg = select('svg').attr('width', width).attr('height', height);
const mercator = geoMercator().scale(30000).translate([width/2, height/2]).center([73,19.7]);
const pathGenerator = geoPath().projection(mercator);
const g = svg.append('g');

// Zoom
svg.call(zoom().on('zoom',() =>{
	g.attr('transform',event.transform)
}))
// Render
const render = data => {
  
let BlockValue  = d => d.properties.Block;
let StuntedValue = d => d.properties.Stunted ;
let SevStuntedValue = d => d.properties.SevStunted ;
let StuntingPValue = d => d.properties.StuntingP ;
let UnderweightPValue = d => d.properties.UnderweightP ;
let LBWPValue = d => d.properties.LBWP ;


// Define the div for the tooltip
const onMouseOver = d =>{	
tooltip.transition().duration(200).style("opacity", .9);		
tooltip.html("<b><h3>"+BlockValue(d)+"</h3></b>"+
             "<hr><b>Stunted child:</b>"+StuntedValue(d)+
             "<br><b>Stunting%:</b>"+StuntingPValue(d)+
             "<br><b>Under Weight child%:</b>"+UnderweightPValue(d)+
             "<br><b>Low Birth Weight%:</b>"+LBWPValue(d)) 
  
    .style("left", d3.event.pageX + "px")
    .style("top",  d3.event.pageY - 30 + "px");	
}
 var tooltip = d3.select("body").append("div") 
        .attr("class", "tooltip")       
        .style("opacity", 0);

  let myColor = (opt,v) =>{
  let min,max,comp;
  if(opt == 1){
    min = d3.min(data,StuntedValue);
    max = d3.max(data,StuntedValue);
    comp = (max - min)/3;
  }else if(opt == 2){
    min = d3.min(data,SevStuntedValue);
    max = d3.max(data,SevStuntedValue);
    comp = (max - min)/3;
  }
 
  if(v>=min && v < min + comp)
    return 'red';
  else if(v >= min+comp && v<max-comp)
    return 'yellow';
  else if(v >= max-comp)
    return 'green';
}
	const paths = g.attr("class", "boundary")
  .selectAll('path').data(data)
  
  const pathEnter = paths.enter().append('path').attr('d',pathGenerator).attr('class','my-block')
  .style("fill", d =>myColor(1,StuntedValue(d))).on("mouseover", d => onMouseOver(d))          
      .on("mouseout", function(d) {   
            tooltip.transition()    
            .duration(500)
            .style("opacity", 0); 
          });
   
  
   g.selectAll("text").data(data)
    .enter().append("text")
    .text(d => BlockValue(d))
    .attr("x",d => pathGenerator.centroid(d)[0])
    .attr("y",d => pathGenerator.centroid(d)[1])
    .attr("text-anchor","middle")
    .attr('font-size','12pt')
    .attr("font-family", "sans-serif");
  
}
//return segregated monthly data
const monthwise = (data) =>{
	let month = {'Aug':[],'Sep':[],'Oct':[]}
  data.forEach(d=>{
  let temp = {};
  temp.block_n = d.block_n
  temp.mdrtly_stntd=+d.mdrtly_stntd
  temp.svrly_stntd=+d.svrly_stntd
  temp.stunting_percent=+d.stunting_percent
  temp.underweight_percent=+d.underweight_percent
  temp.low_birth_weight_percent=+d.low_birth_weight_percent
  month[d.month_n].push(temp)
  })
return month;
}
// month + json =====>>> geojson
const addProperty=(data,json)=>{
  let tempjson = json 
    for (var i = 0; i < data.length; i++) {
    	var dataBlock = data[i].block_n;
      var dataStunted = data[i].mdrtly_stntd;
      var dataSevStunted = data[i].svrly_stntd;
      var dataStuntingP = data[i].stunting_percent;
      var dataUnderweightP = data[i].underweight_percent;
      var dataLBWP = data[i].low_birth_weight_percent;
    for (var j = 0; j < tempjson.features.length; j++)  {
        var jsonBlock = tempjson.features[j].properties.Block;

        if (dataBlock == jsonBlock) {
        tempjson.features[j].properties.Stunted = +dataStunted; 
        tempjson.features[j].properties.SevStunted = +dataSevStunted; 
        tempjson.features[j].properties.StuntingP = +dataStuntingP; 
        tempjson.features[j].properties.UnderweightP = +dataUnderweightP; 
        tempjson.features[j].properties.LBWP = +dataLBWP; 
        break;
      }
    }
    }
  return tempjson.features
}
// aggregated geojson monthwise
const monthwisejson = (monthwiseData,jsonwithblock) =>{
    
  let jsonforaug = JSON.parse(JSON.stringify(jsonwithblock));
  let jsonforsep = JSON.parse(JSON.stringify(jsonwithblock));
  let jsonforoct = JSON.parse(JSON.stringify(jsonwithblock));

  let augJSON = addProperty(monthwiseData.Aug,jsonforaug);
  let sepJSON = addProperty(monthwiseData.Sep,jsonforsep);
  let octJSON = addProperty(monthwiseData.Oct,jsonforoct);

  let jsonMonth = {'Aug':augJSON,'Sep':sepJSON,'Oct':octJSON}

  return jsonMonth;

}
const selectData =  (val,monthwiseJson) =>{
if(val == "aug"){
    	return monthwiseJson.Aug;
  }else if (val == "sep"){
  		return monthwiseJson.Sep;
  }else if (val == 'oct'){
    	return monthwiseJson.Oct       
    }
}
d3.csv("data_monthly.csv").then(data =>{
		const monthwiseData = monthwise(data);
		let myjson = {};
    json('block.geojson').then(json=>{
    const monthwiseJson = monthwisejson(monthwiseData,json);
    d3.select("#monthdropdown")
    .on("change", () =>{
  				let val = document.getElementById("monthdropdown").value
  				let seldata = selectData(val,monthwiseJson);
          g.selectAll("*").remove();
      		render(seldata);
    	});
    render(monthwiseJson.Aug);
    })
})